/**
 * CSS Cache.
 */
export default class ScopedCSSCache {
    private original;
    private scoped;
    /**
     * Returns the scoped CSS.
     *
     * @return {string[]} Scoped style.
     */
    getAllScoped(): string[];
    /**
     * Returns scoped CSS.
     *
     * @param {string} original Original CSS.
     * @return {string} Cached scoped CSS.
     */
    getScoped(original: string): string;
    /**
     * Returns scoped CSS.
     *
     * @param {string} original Original CSS.
     * @param {string} scopedCSS Scoped CSS.
     */
    setScoped(original: string, scopedCSS: string): void;
    /**
     * Removes a cache entry.
     *
     * @param {string} original Original CSS.
     */
    removeScoped(original: string): void;
    /**
     * Returns scope ID.
     *
     * @param {string} original Original CSS.
     * @return string Scope ID.
     */
    getScopeID(original: string): string;
    /**
     * Clears cache.
     */
    clear(): void;
    /**
     * Returns an unique ID.
     *
     * @param {number} index Index.
     * @return {string} ID.
     */
    private getIdByIndex;
}
