/// <reference types="node" />
import VM from 'vm';
import HTMLRenderResult from 'src/html-renderer/HTMLRenderResult';
/**
 * This class is used for rendering a script server side.
 */
export default class VMContext {
    private context;
    /**
     * Returns route HTML.
     *
     * @param {object} options Options.
     * @param {string} options.html HTML.
     * @param {VM.Script} [options.script] Script.
     * @param {string} [options.url] Page URL.
     * @param {boolean} [options.openShadowRoots=false] Set to "true" to open up shadow roots.
     * @param {boolean} [options.extractCSS=true] Set to "true" to extract CSS when opening shadow roots.
     * @param {boolean} [options.scopeCSS=true] Set to "true" to enable scoping of CSS when opening shadow roots.
     * @return {Promise<HTMLRenderResult>} HTML.
     */
    render(options: {
        html: string;
        script: VM.Script;
        url?: string;
        openShadowRoots: boolean;
        extractCSS: boolean;
        scopeCSS: boolean;
    }): Promise<HTMLRenderResult>;
    /**
     * Disposes the render.
     */
    dispose(): void;
    /**
     * Creates a context.
     *
     * @return {VM.Context} Context.
     */
    private createContext;
}
